# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mateco']

package_data = \
{'': ['*']}

install_requires = \
['playsound==1.2.2', 'pyfreetts>=0.1,<0.2', 'text2ipa>=1.4,<2.0']

setup_kwargs = {
    'name': 'mateco',
    'version': '1.4.1',
    'description': 'Master Text Converter',
    'long_description': '<p align="center">\n  <img src="https://raw.githubusercontent.com/tquangsdh20/mateco/main/.github/header.svg">\n</p>\n\n<p align="center"><img src="https://github.com/tquangsdh20/mateco/actions/workflows/test.yml/badge.svg"> <a href="https://codecov.io/github/tquangsdh20/mateco/commit/813bae77e548561e373c9a882199e795c44592a7"><img src="https://codecov.io/gh/tquangsdh20/mateco/branch/main/graphs/badge.svg?branch=main"></a> <img src = "https://img.shields.io/pypi/pyversions/mateco"></p>\n\n## Features\n\n- Support text to speech with many pretty voices options\n- Support download file mp3 from TTS\n- Support convert text to IPA (International Phonetic Alphabet) with English UK and English US\n\n## Installation\n**Windows**\n```\npython -m pip install mateco\n```\n**Linux**\n```\npip install mateco\n```\n**macOS**\n```\nsudo pip3 install mateco\n```\n## How does it work?\n\n### Working with module TTS\n\n#### Setup Language for Converting\n\nTo setup language and voice using the method `setup_voice(language_code)`, where `language_code` :\n\n- English US : `am`\n- English UK : `br`\n- Portuguese (Brazil): `pt-br`\n- Portuguese (Portugal): `pt`\n- The other languages : `ISO LANGUAGE CODE 639-1`\n\n```python\nfrom mateco import TTS\n\n# Initialization for Module TTS\nmod = TTS()\n\n# Choice the voice for America English\nmod.setup_voice(\'am\')\n\n# Convert to audio data\nmod.convert(\'Welcome to Master Text Converter library. I hope it\\\'s useful for you.\')\nmod.speak()\nmod.save_to_file(\'audio.mp3\')\n\n# Change the language\nmod.setup_voice(\'fr\')\nmod.convert(\'Je parle un peu français\')\nmod.speak()\nmod.save_to_file(\'audio_french.mp3\')\nmod.close()\n```\n\nOutput\n\n```\n>> All voices for your language:\n>>    1. Joey - Male - SAPI5\n>>    2. Justin - Male - SAPI5\n>>    3. Matthew - Male - SAPI5\n>>    4. Salli - Female - SAPI5\n>>    5. Joanna - Female - SAPI5\n>>    6. Ivy - Female - SAPI5\n>> Make your choice: 3\n```\n\n### Work with module IPA \n\n#### Initialize module IPA\n\n\n```python\nfrom mateco import IPA\n\n# Setup English UK IPA\nmod = IPA(\'am\')\nen_uk = mod.get_ipa(\'potato, tomato\')\nprint(\'Bristh say:\',en_uk)\n\n# Setup English US IPA\nmod = IPA(\'br\')\nen_us = mod.get_ipa(\'potato, tomato\')\nprint(\'America say:\',en_us)\n\n# Working with Bulk - List of the texts\nbulk = [\'potato\', \'tomato\', \'schedule\']\nresults = mod.get_ipas(bulk)\nprint(results)\n```\n\nOutput\n\n```\n>> Bristh say: pəˈteɪˌtoʊ, təˈmeɪˌtoʊ\n>> America say: pəˈteɪtəʊ, təˈmɑːtəʊ\n>> [\'pəˈteɪtəʊ\', \'təˈmɑːtəʊ\', \'ˈʃɛdjuːl\']\n```\n\n<p align="center">\n  <img src="https://raw.githubusercontent.com/tquangsdh20/mateco/main/.github/footer.svg">\n</p>\n\n<a href="https://github.com/tquangsdh20/mateco"><p align="center"><img src="https://img.shields.io/badge/Github-tquangsdh20-orange?style=social&logo=github"></p></a>',
    'author': 'Joseph Quang',
    'author_email': 'tquangsdh20@fsob.win',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/tquangsdh20/mateco',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
